Cheetah.CheetahWrapper module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.CheetahWrapper module

class `Cheetah.CheetahWrapper.` `Bundle`(**kw)

  Bases: `object`

  Wrap the source, destination and backup paths in one neat little class. Used by CheetahWrapper.getBundles().

class `Cheetah.CheetahWrapper.` `CheetahWrapper`

  Bases: `object`

  `BACKUP_SUFFIX` = '.bak'
  `MAKE_BACKUPS` = True
  `chatter`(format, *args)

    Print a verbose message to stdout. But don’t if .opts.stdout is true or .opts.verbose is false.

  `compile`()
  `debug`(format, *args)

    Print a debugging message to stderr, but don’t if .debug is false.

  `error`(format, *args)

    Always print a warning message to stderr and exit with an error code.

  `fill`()
  `help`()
  `main`(argv=None)

    The main program controller.

  `options`()
  `parseOpts`(args)
  `test`()
  `version`()
  `warn`(format, *args)

    Always print a warning message to stderr.

exception `Cheetah.CheetahWrapper.` `Error`

  Bases: `Exception`

`Cheetah.CheetahWrapper.` `fprintfMessage`(stream, format, *args)

`Cheetah.CheetahWrapper.` `usage`(usageMessage, errorMessage='', out=<_io.TextIOWrapper name='<stderr>' mode='w' encoding='KOI8-R'>)

  Write help text, an optional error message, and abort the program.